/* System headers which libgeda headers rely on */
#include <glib.h>
#include <glib-object.h>
#include <libguile.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <glib/gstdio.h>

/* Public libgeda headers */
#include "defines.h"
#include "struct.h"
#include "s_toplevel.h"
#include "globals.h"
#include "o_types.h"
#include "colors.h"
#include "prototype.h"
#include "funcs.h"
#include "edaconfig.h"
#include "edaerrors.h"

#include "geda_list.h"

/* Private libgeda headers */
#include "defines_priv.h"
#include "struct_priv.h"
#include "prototype_priv.h"
#include "i_vars_priv.h"

/* Gettext translation */
#include "gettext_priv.h"
